@@ -1,42 +1,39 @@
-/******************************************************************************
-*
+/*****************************************************************************
+* 
 * Nagios check_dummy plugin
-*
+* 
 * License: GPL
-* Copyright (c) 1999-2006 nagios-plugins team
-*
-* Last Modified: $Date: 2007-05-24 09:35:53 +0100 (Thu, 24 May 2007) $
-*
+* Copyright (c) 1999-2007 Nagios Plugins Development Team
+* 
+* Last Modified: $Date: 2008-04-27 15:35:26 +0100 (Sun, 27 Apr 2008) $
+* 
 * Description:
-*
+* 
 * This file contains the check_dummy plugin
-*
-*  This plugin will simply return the state corresponding to the numeric value
-*
-*
-* License Information:
-*
-* This program is free software; you can redistribute it and/or modify
+* 
+* This plugin will simply return the state corresponding to the numeric value
+* 
+* 
+* This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
-* the Free Software Foundation; either version 2 of the License, or
+* the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
-*
+* 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
-*
+* 
 * You should have received a copy of the GNU General Public License
-* along with this program; if not, write to the Free Software
-* Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
- $Id: check_dummy.c 1716 2007-05-24 08:35:53Z tonvoon $
- 
-******************************************************************************/
+* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+* 
+* $Id: check_dummy.c 1984 2008-04-27 14:35:26Z dermoth $
+* 
+*****************************************************************************/
 
 const char *progname = "check_dummy";
-const char *revision = "$Revision: 1716 $";
-const char *copyright = "1999-2006";
+const char *revision = "$Revision: 1984 $";
+const char *copyright = "1999-2007";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
 #include "common.h"
@@ -109,11 +106,11 @@ print_help (void)
   printf (COPYRIGHT, copyright, email);
 
   printf ("%s\n", _("This plugin will simply return the state corresponding to the numeric value"));
- 
+
   printf ("%s\n", _("of the <state> argument with optional text"));
 
   printf ("\n\n");
-  
+
   print_usage ();
 
   printf (_(UT_HELP_VRSN));
